==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/email/model/OperationType.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.email.model;

/** Possible operation types. */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20170907")
public enum OperationType implements com.oracle.bmc.http.internal.BmcEnum {
    CreateDkim("CREATE_DKIM"),
    DeleteDkim("DELETE_DKIM"),
    MoveDkim("MOVE_DKIM"),
    UpdateDkim("UPDATE_DKIM"),
    CreateEmailDomain("CREATE_EMAIL_DOMAIN"),
    DeleteEmailDomain("DELETE_EMAIL_DOMAIN"),
    MoveEmailDomain("MOVE_EMAIL_DOMAIN"),
    UpdateEmailDomain("UPDATE_EMAIL_DOMAIN"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private static final org.slf4j.Logger LOG =
            org.slf4j.LoggerFactory.getLogger(OperationType.class);

    private final String value;
    private static java.util.Map<String, OperationType> map;

    static {
        map = new java.util.HashMap<>();
        for (OperationType v : OperationType.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    OperationType(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static OperationType create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'OperationType', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/email/model/OperationType.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.email.model;

/** Possible operation types. */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20170907")
public enum OperationType implements com.oracle.bmc.http.internal.BmcEnum {
    CreateDkim("CREATE_DKIM"),
    DeleteDkim("DELETE_DKIM"),
    MoveDkim("MOVE_DKIM"),
    UpdateDkim("UPDATE_DKIM"),
    CreateEmailDomain("CREATE_EMAIL_DOMAIN"),
    DeleteEmailDomain("DELETE_EMAIL_DOMAIN"),
    MoveEmailDomain("MOVE_EMAIL_DOMAIN"),
    UpdateEmailDomain("UPDATE_EMAIL_DOMAIN"),
    CreateReturnPath("CREATE_RETURN_PATH"),
    DeleteReturnPath("DELETE_RETURN_PATH"),
    UpdateReturnPath("UPDATE_RETURN_PATH"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private static final org.slf4j.Logger LOG =
            org.slf4j.LoggerFactory.getLogger(OperationType.class);

    private final String value;
    private static java.util.Map<String, OperationType> map;

    static {
        map = new java.util.HashMap<>();
        for (OperationType v : OperationType.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    OperationType(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static OperationType create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'OperationType', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}
